{% if user.is_authenticated or group %}
  <button id="webpush-subscribe-button" {% if group %}data-group="{{ group }}"{% endif %} data-url="{{ webpush_save_url }}">
    Subscribe to Push Messaging
  </button>
  <div id="webpush-message" hidden></div>
{% endif %}
