{% if user.is_authenticated or group %}
  {% load static %}

  <script id="webpush-js" type="text/javascript" src="{% static 'webpush/webpush.js' %}"></script>
  {# webpush_serviceworker.js render from template as it needs to be served from the same domain #}
  <meta name="service-worker-js" content="{% url 'serviceworker' %}">
  <meta name="django-webpush-vapid-key" content="{{ vapid_public_key }}">
{% endif %}
